@@ -53,7 +53,6 @@ import platform  # noqa: E402
 import sys  # noqa: E402
 import subprocess  # noqa: E402
 from typing import Any, Dict, List, Optional, TYPE_CHECKING  # noqa: E402
-import unittest  # noqa: E402
 
 import cherrypy  # noqa: E402
 try:
@@ -62,12 +61,9 @@ except ImportError:
     BaseApplication = None  # e.g. on Windows: "ImportError: no module named 'fcntl'".  # noqa: E501
 from wsgiref.simple_server import make_server  # noqa: E402
 
-from cardinal_pythonlib.classes import gen_all_subclasses  # noqa: E402
 from cardinal_pythonlib.fileops import mkdir_p  # noqa: E402
 from cardinal_pythonlib.process import nice_call  # noqa: E402
 from cardinal_pythonlib.ui_commandline import ask_user, ask_user_password  # noqa: E402,E501
-# from cardinal_pythonlib.wsgi.constants import TYPE_WSGI_APP  # noqa: E402,E501
-from cardinal_pythonlib.wsgi.headers_mw import AddHeadersMiddleware  # noqa: E402,E501
 from cardinal_pythonlib.wsgi.request_logging_mw import RequestLoggingMiddleware  # noqa: E402,E501
 from cardinal_pythonlib.wsgi.reverse_proxied_mw import (  # noqa: E402
     ReverseProxiedConfig,
@@ -93,7 +89,6 @@ from camcops_server.cc_modules.cc_constants import (  # noqa: E402
     ConfigDefaults,
     DEFAULT_FLOWER_ADDRESS,
     DEFAULT_FLOWER_PORT,
-    MINIMUM_PASSWORD_LENGTH,
     USER_NAME_FOR_SYSTEM,
 )
 from camcops_server.cc_modules.cc_exception import raise_runtime_error  # noqa: E402,E501
@@ -114,24 +109,16 @@ from camcops_server.cc_modules.cc_taskindex import (  # noqa: E402
     reindex_everything,
 )
 # noinspection PyUnresolvedReferences
-from camcops_server.cc_modules.cc_tracker import TrackerCtvTests  # import side effects (register unit test)  # noqa: E402,F401,E501
-from camcops_server.cc_modules.cc_unittest import (  # noqa: E402
-    DemoDatabaseTestCase,
-    DemoRequestTestCase,
-    ExtendedTestCase,
-)
 from camcops_server.cc_modules.cc_user import (  # noqa: E402
     SecurityLoginFailure,
     set_password_directly,
     User,
 )
+from camcops_server.cc_modules.cc_validators import validate_new_password  # noqa: E402,E501
 from camcops_server.cc_modules.celery import (  # noqa: E402
     CELERY_APP_NAME,
     CELERY_SOFT_TIME_LIMIT_SEC,
 )
-# noinspection PyUnresolvedReferences
-from camcops_server.cc_modules.webview import WebviewTests  # import side effects (register unit test)  # noqa
-
 log.info("Imports complete")
 log.info("Using {} tasks", len(Task.all_subclasses_by_tablename()))
 
@@ -287,44 +274,7 @@ def make_wsgi_app(debug_toolbar: bool = False,
             static_cache_duration_s=static_cache_duration_s) as config:
         app = config.make_wsgi_app()
 
-    # Middleware above the Pyramid level
-
-    # noinspection PyTypeChecker
-    app = AddHeadersMiddleware(app, headers=[
-        # From ZAP penetration testing:
-        ("X-Frame-Options", "DENY"),
-        # ... or "X-Frame-Options Header Not Set"
-        ("X-Content-Type-Options", "nosniff"),
-        # ... or "X-Content-Type-Options Header Missing"
-
-        # NOT THIS:
-        #       ("Cache-Control", "no-cache, no-store, must-revalidate"),
-        # ... or "Incomplete or No Cache-control and Pragma HTTP Header Set"
-        # ... note that Pragma is HTTP/1.0 and cache-control is HTTP/1.1, so
-        #     you don't have to do both.
-        # BUT that prevents caching of images (e.g. logos), and we don't want
-        # that.
-        #
-        # The Pyramid @view_config decorator (or add_view function) takes an
-        # "http_cache" parameter, as per
-        # https://pyramid-pt-br.readthedocs.io/en/latest/api/config.html#pyramid.config.Configurator.add_view  # noqa
-        # and it looks like viewderivers.py implements this. The default does
-        # not set the HTTP "cache-control" header, explained at
-        # https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Cache-Control  # noqa
-        # The basic options are:
-        # - 0: do not cache
-        # - integer_seconds, or datetime.timedelta: lifespan
-        # - tuple (lifespan, dictionary_of_extra_cache_control_details)
-        # - tuple (None, dictionary_of_extra_cache_control_details)
-        # We now set http_cache for all our views via view_config, as well as
-        # the equivalent of using cache_max_age for add_static_view().
-
-        # However, this (as an additional Cache-Control header -- as well as
-        # any "cache, it's static" or "don't cache" header) sorts out any ZAP
-        # complaints:
-        ("Cache-Control", 'no-cache="Set-Cookie, Set-Cookie2"'),
-
-    ])  # type: Router
+    # Add any middleware above the Pyramid level:
 
     if show_requests:
         # noinspection PyTypeChecker
@@ -585,9 +535,10 @@ def get_new_password_from_cli(username: str) -> str:
     """
     while True:
         password1 = ask_user_password(f"New password for user {username}")
-        if not password1 or len(password1) < MINIMUM_PASSWORD_LENGTH:
-            log.error("... passwords can't be blank or shorter than {} "
-                      "characters", MINIMUM_PASSWORD_LENGTH)
+        try:
+            validate_new_password(password1)
+        except ValueError as e:
+            log.error(str(e))
             continue
         password2 = ask_user_password(
             f"New password for user {username} (again)")
@@ -943,89 +894,6 @@ def launch_celery_flower(
     nice_call(cmdargs, cleanup_timeout=cleanup_timeout_s)
 
 
-# =============================================================================
-# Test rig
-# =============================================================================
-
-def self_test(show_only: bool = False,
-              test_class: str = None,
-              failfast: bool = False) -> bool:
-    """
-    Run unit tests that are in the class(es) whose names contain test_class.
-    If test_class is None, run all the tests.
-
-    Args:
-        show_only:
-            If True, just display the names of test classes, don't run them.
-        test_class:
-            Test class(es) to run.
-        failfast:
-            Stop on first error?
-
-    Returns:
-        When running tests, returns True if test run was successful, otherwise
-        False.
-        When displaying the names of test classes returns True always.
-    """
-    ok = True
-
-    # If you use this:
-    #       loader = TestLoader()
-    #       suite = loader.discover(CAMCOPS_SERVER_DIRECTORY)
-    # ... then it fails because submodules contain relative imports (e.g.
-    # "from ..cc_modules.something import x" and this gives "ValueError:
-    # attemped relative import beyond top-level package". As the unittest
-    # docs say, "In order to be compatible with test discovery, all of the
-    # test files must be modules or packages... importable from the
-    # top-level directory of the project".
-    #
-    # However, having imported everything, all our tests should be
-    # subclasses of TestCase... but so are some other things.
-    #
-    # So we have a choice:
-    # 1. manual test specification (yuk)
-    # 2. hack around TestCase.__subclasses__ to exclude "built-in" ones
-    # 3. abandon relative imports
-    #   ... not a bad general idea (they often seem to cause problems!)
-    #   ... however, the discovery process (a) fails with importing
-    #       "alembic.versions", but more problematically, imports tasks
-    #       twice, which gives errors like
-    #       "sqlalchemy.exc.InvalidRequestError: Table 'ace3' is already
-    #       defined for this MetaData instance."
-    # So, hack it is.
-
-    # noinspection PyProtectedMember,PyUnresolvedReferences
-    skip_testclass_subclasses = [
-        # The ugly hack: what you see from
-        # unittest.TestCase.__subclasses__() from a clean import:
-        unittest.case.FunctionTestCase,  # built in
-        unittest.case._SubTest,  # built in
-        unittest.loader._FailedTest,  # built in
-        # plus our extras:
-        DemoDatabaseTestCase,  # our base class
-        DemoRequestTestCase,  # also a base class
-        ExtendedTestCase,  # also a base class
-    ]
-    suite = unittest.TestSuite()
-    for cls in gen_all_subclasses(unittest.TestCase):
-        if cls in skip_testclass_subclasses:
-            continue
-        if not cls.__module__.startswith("camcops_server"):
-            # don't, for example, run cardinal_pythonlib self-tests
-            continue
-        if test_class is None or test_class in cls.__name__:
-            log.info("Discovered test: {}", cls)
-            # noinspection PyUnresolvedReferences
-            suite.addTest(unittest.makeSuite(cls))
-    if not show_only:
-        runner = unittest.TextTestRunner(failfast=failfast)
-        result = runner.run(suite)
-
-        ok = result.wasSuccessful()
-
-    return ok
-
-
 def dev_cli() -> None:
     """
     Fire up a developer debug command-line.
