@@ -76,7 +76,6 @@ import os
 import logging
 import re
 from typing import Any, Dict, Generator, List, Optional, Union
-from unittest import TestCase
 
 from cardinal_pythonlib.configfiles import (
     get_config_parameter,
@@ -133,7 +132,6 @@ from camcops_server.cc_modules.cc_exception import raise_runtime_error
 from camcops_server.cc_modules.cc_filename import (
     PatientSpecElementForFilename,
 )
-from camcops_server.cc_modules.cc_group import is_group_name_valid
 from camcops_server.cc_modules.cc_language import POSSIBLE_LOCALES
 from camcops_server.cc_modules.cc_pyramid import MASTER_ROUTE_CLIENT_API
 from camcops_server.cc_modules.cc_snomed import (
@@ -142,6 +140,10 @@ from camcops_server.cc_modules.cc_snomed import (
     get_icd10_snomed_concepts_from_xml,
     SnomedConcept,
 )
+from camcops_server.cc_modules.cc_validators import (
+    validate_export_recipient_name,
+    validate_group_name,
+)
 from camcops_server.cc_modules.cc_version_string import (
     CAMCOPS_SERVER_VERSION_STRING,
 )
@@ -1213,8 +1215,7 @@ class CamcopsConfig(object):
                                  f"for {xml_taskname!r}")
             groupnames = [x.strip() for x in groupnames.split(",")]
             for gn in groupnames:
-                if not is_group_name_valid(gn):
-                    raise ValueError(f"Invalid group name: {gn!r}")
+                validate_group_name(gn)
             self.restricted_tasks[xml_taskname] = groupnames
 
         self.session_timeout_minutes = _get_int(
@@ -1672,6 +1673,10 @@ class CamcopsConfig(object):
         self._export_recipients = []  # type: List[ExportRecipientInfo]
         for recip_name in self.export_recipient_names:
             log.debug("Loading export config for recipient {!r}", recip_name)
+            try:
+                validate_export_recipient_name(recip_name)
+            except ValueError as e:
+                raise ValueError(f"Bad recipient name {recip_name!r}: {e}")
             recipient = ExportRecipientInfo.read_from_config(
                 self, parser=parser, recipient_name=recip_name)
             self._export_recipients.append(recipient)
@@ -1795,56 +1800,3 @@ def get_default_config_from_os_env() -> CamcopsConfig:
         return CamcopsConfig(config_filename="", config_text=get_demo_config())
     else:
         return get_config(get_config_filename_from_os_env())
-
-
-# =============================================================================
-# Unit tests
-# =============================================================================
-
-class EmailConfigTests(TestCase):
-
-    def setUp(self):
-        super().setUp()
-
-        from io import StringIO
-
-        # Start with a working config and just set the things we want to test
-        config_text = get_demo_config()
-        self.parser = configparser.ConfigParser()
-        self.parser.read_string(config_text)
-
-        self.parser.set("export", "RECIPIENTS", "recipient_A")
-        self.parser.set("recipient:recipient_A", "TRANSMISSION_METHOD", "email")
-
-        self.parser.set("site", "EMAIL_HOST", "smtp.example.com")
-        self.parser.set("site", "EMAIL_PORT", "587")
-        self.parser.set("site", "EMAIL_USE_TLS", "true")
-        self.parser.set("site", "EMAIL_HOST_USERNAME", "username")
-        self.parser.set("site", "EMAIL_HOST_PASSWORD", "mypassword")
-        self.parser.set("site", "EMAIL_FROM",
-                        "CamCOPS computer <from@example.com>")
-        self.parser.set("site", "EMAIL_SENDER",
-                        "CamCOPS computer <sender@example.com>")
-        self.parser.set("site", "EMAIL_REPLY_TO",
-                        "CamCOPS clinical administrator <admin@example.com>")
-
-        with StringIO() as buffer:
-            self.parser.write(buffer)
-            self.config = CamcopsConfig(config_filename="",
-                                        config_text=buffer.getvalue())
-
-    def test_export_recipients_use_site_email_config(self) -> None:
-        recipient = self.config._export_recipients[0]
-        self.assertEqual(recipient.recipient_name, "recipient_A")
-
-        self.assertEqual(recipient.email_host, "smtp.example.com")
-        self.assertEqual(recipient.email_port, 587)
-        self.assertTrue(recipient.email_use_tls)
-        self.assertEqual(recipient.email_host_username, "username")
-        self.assertEqual(recipient.email_host_password, "mypassword")
-        self.assertEqual(recipient.email_from,
-                         "CamCOPS computer <from@example.com>")
-        self.assertEqual(recipient.email_sender,
-                         "CamCOPS computer <sender@example.com>")
-        self.assertEqual(recipient.email_reply_to,
-                         "CamCOPS clinical administrator <admin@example.com>")
