@@ -97,12 +97,10 @@ Also notes:
 # Imports
 # =============================================================================
 
-import datetime
 import json
 import logging
 from typing import (Any, Generator, List, Optional, Tuple, Type, TYPE_CHECKING,
                     Union)
-import unittest
 import uuid
 
 from cardinal_pythonlib.datetimefunc import (
@@ -115,16 +113,13 @@ from cardinal_pythonlib.datetimefunc import (
 from cardinal_pythonlib.lists import chunks
 from cardinal_pythonlib.logs import (
     BraceStyleAdapter,
-    main_only_quicksetup_rootlogger,
 )
-from cardinal_pythonlib.randomness import create_base64encoded_randomness
 from cardinal_pythonlib.reprfunc import auto_repr
 from cardinal_pythonlib.sqlalchemy.dialect import SqlaDialectName
 from cardinal_pythonlib.sqlalchemy.orm_inspect import (
     gen_columns,
     gen_relationships,
 )
-from cardinal_pythonlib.sqlalchemy.session import SQLITE_MEMORY_URL
 from cardinal_pythonlib.sqlalchemy.sqlfunc import (
     fail_unknown_dialect,
     fetch_processed_single_clause
@@ -140,13 +135,12 @@ from sqlalchemy.ext.compiler import compiles
 from sqlalchemy.orm.relationships import RelationshipProperty
 from sqlalchemy.sql.elements import conv
 from sqlalchemy.sql.expression import text
-from sqlalchemy.sql.functions import func, FunctionElement
+from sqlalchemy.sql.functions import FunctionElement
 from sqlalchemy.sql.schema import Column
 from sqlalchemy.sql.sqltypes import (
     Boolean,
     CHAR,
     DateTime,
-    Integer,
     LargeBinary,
     String,
     Text,
@@ -155,7 +149,7 @@ from sqlalchemy.sql.sqltypes import (
 )
 from sqlalchemy.sql.type_api import TypeDecorator
 
-from camcops_server.cc_modules.cc_constants import PV
+from camcops_server.cc_modules.cc_constants import PV, StringLengths
 from camcops_server.cc_modules.cc_simpleobjects import IdNumReference
 from camcops_server.cc_modules.cc_sqlalchemy import (
     LONG_COLUMN_NAME_WARNING_LIMIT,
@@ -191,188 +185,6 @@ if any([DEBUG_DATETIME_AS_ISO_TEXT,
 # =============================================================================
 # Constants
 # =============================================================================
-#
-# Note: "191" relates to MySQL indexing of VARCHAR fields using utf8mb4;
-# - https://stackoverflow.com/questions/6172798/
-# - https://dev.mysql.com/doc/refman/5.7/en/innodb-restrictions.html
-# There are alternative workarounds, but these fields are OK at 191.
-#
-# Re commenting variables in Sphinx:
-# - https://stackoverflow.com/questions/20227051/how-to-document-a-module-constant-in-python  # noqa
-# - http://www.sphinx-doc.org/en/master/usage/extensions/autodoc.html#directive-autodata  # noqa
-# - URLs are a bit tricky; the colons get re-interpreted sometimes; it seems
-#   that inserting an extra colon after "#:", e.g. "#: : see http://somewhere"
-#   works.
-# - If a comment needs "# noqa" for the linter, then make it a docstring,
-#   because it will appear in the Sphinx string.
-
-AUDIT_SOURCE_MAX_LEN = 20  #: our choice based on use in CamCOPS code
-
-#: : See https://docs.python.org/3.7/library/codecs.html#standard-encodings.
-#: Probably ~18 so give it some headroom.
-CHARSET_MAX_LEN = 64
-
-CURRENCY_MAX_LEN = 3  #: Can have Unicode symbols like € or text like "GBP"
-
-DATABASE_TITLE_MAX_LEN = 255  #: our choice
-
-#: 191 is the maximum for MySQL + InnoDB + VARCHAR + utf8mb4 + index;
-#: must be compatible with tablet
-DEVICE_NAME_MAX_LEN = 191
-
-#: : See https://en.wikipedia.org/wiki/Email_address.
-EMAIL_ADDRESS_MAX_LEN = 255
-
-#: 191 is the maximum for MySQL + InnoDB + VARCHAR + utf8mb4 + index
-EXPORT_RECIPIENT_NAME_MAX_LEN = 191
-
-#: Our choice
-FILTER_TEXT_MAX_LEN = 255
-
-#: Our choice; used for user full names on the server
-FULLNAME_MAX_LEN = 255
-
-#: Our choice
-FILESPEC_MAX_LEN = 255
-
-#: Our choice
-GROUP_DESCRIPTION_MAX_LEN = 255
-
-#: 191 is the maximum for MySQL + InnoDB + VARCHAR + utf8mb4 + index
-GROUP_NAME_MAX_LEN = 191
-
-HASHED_PW_MAX_LEN = 60
-"""
-:
-We use ``bcrypt``. Empirically, the length of its hashed output is:
-
-.. code-block:: none
-
-       "$2a$" (4)
-       cost parameter, e.g. "$09" for 9 rounds (3)
-       b64-enc 128-bit salt (22)
-       b64enc 184-bit hash (31)
-
-    ... total 60
-
-See https://stackoverflow.com/questions/5881169/what-column-type-length-should-i-use-for-storing-a-bcrypt-hashed-password-in-a-d
-"""  # noqa
-
-HOSTNAME_MAX_LEN = 255
-"""
-FQDN; see
-https://stackoverflow.com/questions/8724954/what-is-the-maximum-number-of-characters-for-a-host-name-in-unix
-"""  # noqa
-
-ICD9_CODE_MAX_LEN = 6
-"""
-Longest is "xxx.xx"; thus, 6; see
-https://www.cms.gov/Medicare/Quality-Initiatives-Patient-Assessment-Instruments/HospitalQualityInits/Downloads/HospitalAppendix_F.pdf
-"""  # noqa
-
-#: longest is e.g. "F00.000"; "F10.202"; thus, 7
-ICD10_CODE_MAX_LEN = 7
-
-DIAGNOSTIC_CODE_MAX_LEN = max(ICD9_CODE_MAX_LEN, ICD10_CODE_MAX_LEN)
-
-HL7_AA_MAX_LEN = 20
-"""
-- The AA appears in Table 4.6 "Extended composite ID", p46-47 of
-  hl7guide-1-4-2012-08.pdf
-- ... but is defined in Table 4.9 "Entity Identifier", p50, in which:
-
-  - component 2 is the Assigning Authority (see component 1)
-  - component 2 is also a Namespace ID with a length of 20
-
-- ... and multiple other examples of an Assigning Authority being one example
-  of a Namespace ID
-
-- ... and examples are in Table 0363 (p229 of the PDF), which are all 3-char.
-
-- ... and several other examples of "Namespace ID" being of length 1..20
-  meaning 1-20.
-"""
-
-HL7_ID_TYPE_MAX_LEN = 5
-"""
-Table 4.6 "Extended composite ID", p46-47 of hl7guide-1-4-2012-08.pdf,
-and Table 0203 "Identifier type", p204 of that PDF, in Appendix B.
-"""
-
-#: Our choice
-ID_DESCRIPTOR_MAX_LEN = 255
-
-#: Our choice
-ID_POLICY_MAX_LEN = 255
-
-#: : See http://stackoverflow.com/questions/166132
-IP_ADDRESS_MAX_LEN = 45
-
-ISO8601_DATETIME_STRING_MAX_LEN = 32
-"""
-Max length e.g.
-
-.. code-block:: none
-
-    2013-07-24T20:04:07.123456+01:00
-    1234567890123456789012345678901234567890
-
-(with punctuation, T, microseconds, colon in timezone).
-"""
-
-#: See :func:`cardinal_pythonlib.datetimefunc.duration_to_iso`
-ISO8601_DURATION_STRING_MAX_LEN = 29
-
-LANGUAGE_CODE_MAX_LEN = 6  # two-letter language, hyphen, 2/3-letter country
-
-# LONGBLOB_LONGTEXT_MAX_LEN = (2 ** 32) - 1
-# ... https://dev.mysql.com/doc/refman/8.0/en/storage-requirements.html
-
-#: See https://stackoverflow.com/questions/643690
-MIMETYPE_MAX_LEN = 255
-
-#: For forename and surname, each; our choice but must match tablet
-PATIENT_NAME_MAX_LEN = 255
-
-RFC_2822_DATE_MAX_LEN = 31
-"""
-e.g. ``Fri, 09 Nov 2001 01:08:47 -0000``; 3.3 in
-https://tools.ietf.org/html/rfc2822, assuming extra white space not added
-"""
-
-#: for export; our choice based on use in CamCOPS code
-SENDING_FORMAT_MAX_LEN = 50
-
-#: our choice; 64 bytes => 512 bits, which is a lot in 2017
-SESSION_TOKEN_MAX_BYTES = 64
-
-SESSION_TOKEN_MAX_LEN = len(
-    create_base64encoded_randomness(SESSION_TOKEN_MAX_BYTES))
-
-TABLENAME_MAX_LEN = 128
-"""
-For
-
-- MySQL: 64 -- https://dev.mysql.com/doc/refman/5.7/en/identifiers.html
-- SQL Server: 128  -- https://msdn.microsoft.com/en-us/library/ms191240.aspx
-- Oracle: 32, then 128 from v12.2 (2017)
-"""
-
-TASK_SUMMARY_TEXT_FIELD_DEFAULT_MAX_LEN = 50
-"""
-... our choice, contains short strings like "normal", "abnormal", "severe".
-Easy to change, since it's only used when exporting summaries, and not in
-the core database.
-"""
-
-#: Our choice
-URL_MAX_LEN = 255
-
-#: 191 is the maximum for MySQL + InnoDB + VARCHAR + utf8mb4 + index
-USERNAME_CAMCOPS_MAX_LEN = 191
-
-#: Our choice
-USERNAME_EXTERNAL_MAX_LEN = 255
 
 
 class RelationshipInfo(object):
@@ -390,7 +202,7 @@ class RelationshipInfo(object):
 # =============================================================================
 # If you insert something too long into a VARCHAR, it just gets truncated.
 
-AuditSourceColType = String(length=AUDIT_SOURCE_MAX_LEN)
+AuditSourceColType = String(length=StringLengths.AUDIT_SOURCE_MAX_LEN)
 
 # BigIntUnsigned = Integer().with_variant(mysql.BIGINT(unsigned=True), 'mysql')
 # ... partly because Alembic breaks on variants (Aug 2017), and partly because
@@ -398,26 +210,29 @@ AuditSourceColType = String(length=AUDIT_SOURCE_MAX_LEN)
 #     BigInteger (2017-08-25).
 
 CharColType = String(length=1)
-CharsetColType = String(length=CHARSET_MAX_LEN)
-CurrencyColType = Unicode(length=CURRENCY_MAX_LEN)
+CharsetColType = String(length=StringLengths.CHARSET_MAX_LEN)
+CurrencyColType = Unicode(length=StringLengths.CURRENCY_MAX_LEN)
 
-DatabaseTitleColType = Unicode(length=DATABASE_TITLE_MAX_LEN)
-DeviceNameColType = String(length=DEVICE_NAME_MAX_LEN)
-DiagnosticCodeColType = String(length=DIAGNOSTIC_CODE_MAX_LEN)
+DatabaseTitleColType = Unicode(length=StringLengths.DATABASE_TITLE_MAX_LEN)
+DeviceNameColType = String(length=StringLengths.DEVICE_NAME_MAX_LEN)
+DiagnosticCodeColType = String(length=StringLengths.DIAGNOSTIC_CODE_MAX_LEN)
 
-EmailAddressColType = Unicode(length=EMAIL_ADDRESS_MAX_LEN)
-EraColType = String(length=ISO8601_DATETIME_STRING_MAX_LEN)  # underlying SQL type  # noqa
-ExportRecipientNameColType = String(length=EXPORT_RECIPIENT_NAME_MAX_LEN)
-ExportTransmissionMethodColType = String(length=SENDING_FORMAT_MAX_LEN)
+EmailAddressColType = Unicode(length=StringLengths.EMAIL_ADDRESS_MAX_LEN)
+EraColType = String(length=StringLengths.ISO8601_DATETIME_STRING_MAX_LEN)
+ExportRecipientNameColType = String(
+    length=StringLengths.EXPORT_RECIPIENT_NAME_MAX_LEN)
+ExportTransmissionMethodColType = String(
+    length=StringLengths.SENDING_FORMAT_MAX_LEN)
 
-FilterTextColType = Unicode(length=FILTER_TEXT_MAX_LEN)
-FileSpecColType = Unicode(length=FILESPEC_MAX_LEN)
-FullNameColType = Unicode(length=FULLNAME_MAX_LEN)
+FilterTextColType = Unicode(length=StringLengths.FILTER_TEXT_MAX_LEN)
+FileSpecColType = Unicode(length=StringLengths.FILESPEC_MAX_LEN)
+FullNameColType = Unicode(length=StringLengths.FULLNAME_MAX_LEN)
 
-GroupDescriptionColType = Unicode(length=GROUP_DESCRIPTION_MAX_LEN)
-GroupNameColType = Unicode(length=GROUP_NAME_MAX_LEN)
+GroupDescriptionColType = Unicode(
+    length=StringLengths.GROUP_DESCRIPTION_MAX_LEN)
+GroupNameColType = Unicode(length=StringLengths.GROUP_NAME_MAX_LEN)
 
-HashedPasswordColType = String(length=HASHED_PW_MAX_LEN)
+HashedPasswordColType = String(length=StringLengths.HASHED_PW_MAX_LEN)
 # ... You might think that we must ensure case-SENSITIVE comparison on this
 # field. That would require the option collation='utf8mb4_bin' to String(),
 # for MySQL. However, that is MySQL-specific, and SQLAlchemy currently (Oct
@@ -428,18 +243,18 @@ HashedPasswordColType = String(length=HASHED_PW_MAX_LEN)
 # comparison in Python (see calls to is_password_valid()). So the database
 # collation doesn't matter. So we don't set it.
 # See further notes in cc_sqlalchemy.py
-HL7AssigningAuthorityType = String(length=HL7_AA_MAX_LEN)
-HL7IdTypeType = String(length=HL7_ID_TYPE_MAX_LEN)
-HostnameColType = String(length=HOSTNAME_MAX_LEN)
+HL7AssigningAuthorityType = String(length=StringLengths.HL7_AA_MAX_LEN)
+HL7IdTypeType = String(length=StringLengths.HL7_ID_TYPE_MAX_LEN)
+HostnameColType = String(length=StringLengths.HOSTNAME_MAX_LEN)
 
-IdDescriptorColType = Unicode(length=ID_DESCRIPTOR_MAX_LEN)
-IdPolicyColType = String(length=ID_POLICY_MAX_LEN)
+IdDescriptorColType = Unicode(length=StringLengths.ID_DESCRIPTOR_MAX_LEN)
+IdPolicyColType = String(length=StringLengths.ID_POLICY_MAX_LEN)
 # IntUnsigned = Integer().with_variant(mysql.INTEGER(unsigned=True), 'mysql')
-IPAddressColType = String(length=IP_ADDRESS_MAX_LEN)
+IPAddressColType = String(length=StringLengths.IP_ADDRESS_MAX_LEN)
 # This is a plain string.
 # See also e.g. http://sqlalchemy-utils.readthedocs.io/en/latest/_modules/sqlalchemy_utils/types/ip_address.html  # noqa
 
-LanguageCodeColType = String(length=LANGUAGE_CODE_MAX_LEN)
+LanguageCodeColType = String(length=StringLengths.LANGUAGE_CODE_MAX_LEN)
 
 # Large BLOB:
 # https://stackoverflow.com/questions/43791725/sqlalchemy-how-to-make-a-longblob-column-in-mysql  # noqa
@@ -452,21 +267,24 @@ LongBlob = LargeBinary().with_variant(mysql.LONGBLOB, "mysql")
 LongText = UnicodeText().with_variant(mysql.LONGTEXT, "mysql")
 # LongText = UnicodeText(length=LONGBLOB_LONGTEXT_MAX_LEN)  # doesn't translate to SQL Server  # noqa
 
-MimeTypeColType = String(length=MIMETYPE_MAX_LEN)
+MimeTypeColType = String(length=StringLengths.MIMETYPE_MAX_LEN)
 
-PatientNameColType = Unicode(length=PATIENT_NAME_MAX_LEN)
+PatientNameColType = Unicode(length=StringLengths.PATIENT_NAME_MAX_LEN)
 
-Rfc2822DateColType = String(length=RFC_2822_DATE_MAX_LEN)
+Rfc2822DateColType = String(length=StringLengths.RFC_2822_DATE_MAX_LEN)
 
-SessionTokenColType = String(length=SESSION_TOKEN_MAX_LEN)
+SessionTokenColType = String(length=StringLengths.SESSION_TOKEN_MAX_LEN)
 SexColType = String(length=1)
-SummaryCategoryColType = String(length=TASK_SUMMARY_TEXT_FIELD_DEFAULT_MAX_LEN)  # pretty generic  # noqa
+SummaryCategoryColType = String(
+    length=StringLengths.TASK_SUMMARY_TEXT_FIELD_DEFAULT_MAX_LEN)
+# ... pretty generic
 
-TableNameColType = String(length=TABLENAME_MAX_LEN)
+TableNameColType = String(length=StringLengths.TABLENAME_MAX_LEN)
 
-UrlColType = String(length=URL_MAX_LEN)
-UserNameCamcopsColType = String(length=USERNAME_CAMCOPS_MAX_LEN)
-UserNameExternalColType = String(length=USERNAME_EXTERNAL_MAX_LEN)
+UrlColType = String(length=StringLengths.URL_MAX_LEN)
+UserNameCamcopsColType = String(length=StringLengths.USERNAME_CAMCOPS_MAX_LEN)
+UserNameExternalColType = String(
+    length=StringLengths.USERNAME_EXTERNAL_MAX_LEN)
 
 
 # =============================================================================
@@ -835,7 +653,8 @@ class PendulumDateTimeAsIsoTextColType(TypeDecorator):
     Uses Pendulum on the Python side.
     """
 
-    impl = String(length=ISO8601_DATETIME_STRING_MAX_LEN)  # underlying SQL type  # noqa
+    impl = String(length=StringLengths.ISO8601_DATETIME_STRING_MAX_LEN)
+    # ... underlying SQL type
 
     _coltype_name = "PendulumDateTimeAsIsoTextColType"
 
@@ -974,7 +793,8 @@ class PendulumDurationAsIsoTextColType(TypeDecorator):
     Uses :class:`pendulum.Duration` on the Python side.
     """
 
-    impl = String(length=ISO8601_DURATION_STRING_MAX_LEN)  # underlying SQL type  # noqa
+    impl = String(length=StringLengths.ISO8601_DURATION_STRING_MAX_LEN)
+    # ... underlying SQL type
 
     _coltype_name = "PendulumDurationAsIsoTextColType"
 
@@ -1767,227 +1587,3 @@ class BoolColumn(CamcopsColumn):
         """
         kwargs["constraint_name"] = self.constraint_name
         return super()._constructor(*args, **kwargs)
-
-
-# =============================================================================
-# Unit testing
-# =============================================================================
-
-class SqlaColtypesTest(unittest.TestCase):
-    """
-    Unit tests.
-    """
-    # don't inherit from ExtendedTestCase; circular import
-
-    @staticmethod
-    def _assert_dt_equal(a: Union[datetime.datetime, Pendulum],
-                         b: Union[datetime.datetime, Pendulum]) -> None:
-        # Accept that one may have been truncated or rounded to milliseconds.
-        a = coerce_to_pendulum(a)
-        b = coerce_to_pendulum(b)
-        diff = a - b
-        assert diff.microseconds < 1000, f"{a!r} != {b!r}"
-
-    def test_iso_datetime_field(self) -> None:
-        log.info("test_iso_datetime_field")
-
-        # from pprint import pformat
-        import pendulum
-        from sqlalchemy.engine import create_engine
-        from sqlalchemy.sql.expression import select
-        from sqlalchemy.sql.schema import MetaData, Table
-
-        engine = create_engine(SQLITE_MEMORY_URL, echo=True)
-        meta = MetaData()
-        meta.bind = engine  # adds execute() method to select() etc.
-        # ... http://docs.sqlalchemy.org/en/latest/core/connections.html
-
-        id_colname = 'id'
-        dt_local_colname = 'dt_local'
-        dt_utc_colname = 'dt_utc'
-        iso_colname = 'iso'
-        id_col = Column(id_colname, Integer, primary_key=True)
-        dt_local_col = Column(dt_local_colname, DateTime)
-        dt_utc_col = Column(dt_utc_colname, DateTime)
-        iso_col = Column(iso_colname, PendulumDateTimeAsIsoTextColType)
-
-        table = Table('testtable', meta,
-                      id_col, dt_local_col, dt_utc_col, iso_col)
-        table.create()
-
-        now = Pendulum.now()
-        now_utc = now.in_tz(pendulum.UTC)
-        yesterday = now.subtract(days=1)
-        yesterday_utc = yesterday.in_tz(pendulum.UTC)
-
-        table.insert().values([
-            {
-                id_colname: 1,
-                dt_local_colname: now,
-                dt_utc_colname: now_utc,
-                iso_colname: now,
-            },
-            {
-                id_colname: 2,
-                dt_local_colname: yesterday,
-                dt_utc_colname: yesterday_utc,
-                iso_colname: yesterday
-            },
-        ]).execute()
-        select_fields = [
-            id_col,
-            dt_local_col,
-            dt_utc_col,
-            iso_col,
-            func.length(dt_local_col).label("len_dt_local_col"),
-            func.length(dt_utc_col).label("len_dt_utc_col"),
-            func.length(iso_col).label("len_iso_col"),
-            isotzdatetime_to_utcdatetime(iso_col).label("iso_to_utcdt"),
-            unknown_field_to_utcdatetime(dt_utc_col).label("uk_utcdt_to_utcdt"),
-            unknown_field_to_utcdatetime(iso_col).label("uk_iso_to_utc_dt"),
-        ]
-        rows = list(
-            select(select_fields)
-            .select_from(table)
-            .order_by(id_col)
-            .execute()
-        )
-        # for row in rows:
-        #     log.debug("\n{}", pformat(dict(row)))
-        self._assert_dt_equal(rows[0][dt_local_col], now)
-        self._assert_dt_equal(rows[0][dt_utc_col], now_utc)
-        self._assert_dt_equal(rows[0][iso_colname], now)
-        self._assert_dt_equal(rows[0]["iso_to_utcdt"], now_utc)
-        self._assert_dt_equal(rows[0]["uk_utcdt_to_utcdt"], now_utc)
-        self._assert_dt_equal(rows[0]["uk_iso_to_utc_dt"], now_utc)
-        self._assert_dt_equal(rows[1][dt_local_col], yesterday)
-        self._assert_dt_equal(rows[1][dt_utc_col], yesterday_utc)
-        self._assert_dt_equal(rows[1][iso_colname], yesterday)
-        self._assert_dt_equal(rows[1]["iso_to_utcdt"], yesterday_utc)
-        self._assert_dt_equal(rows[1]["uk_utcdt_to_utcdt"], yesterday_utc)
-        self._assert_dt_equal(rows[1]["uk_iso_to_utc_dt"], yesterday_utc)
-
-    @staticmethod
-    def _assert_duration_equal(a: Duration, b: Duration) -> None:
-        assert a == b, f"{a!r} != {b!r}"
-
-    def test_iso_duration_field(self) -> None:
-        log.info("test_iso_duration_field")
-
-        from sqlalchemy.engine import create_engine
-        from sqlalchemy.sql.expression import select
-        from sqlalchemy.sql.schema import MetaData, Table
-
-        # As above:
-        engine = create_engine(SQLITE_MEMORY_URL, echo=True)
-        meta = MetaData()
-        meta.bind = engine
-
-        id_colname = 'id'
-        duration_colname = 'duration_iso'
-        id_col = Column(id_colname, Integer, primary_key=True)
-        duration_col = Column(duration_colname,
-                              PendulumDurationAsIsoTextColType)
-
-        table = Table('testtable', meta,
-                      id_col, duration_col)
-        table.create()
-
-        d1 = Duration(years=1, months=3, seconds=3, microseconds=4)
-        d2 = Duration(seconds=987.654321)
-        d3 = Duration(days=-5)
-
-        table.insert().values([
-            {
-                id_colname: 1,
-                duration_colname: d1,
-            },
-            {
-                id_colname: 2,
-                duration_colname: d2,
-            },
-            {
-                id_colname: 3,
-                duration_colname: d3,
-            },
-        ]).execute()
-        select_fields = [
-            id_col,
-            duration_col,
-        ]
-        rows = list(
-            select(select_fields)
-            .select_from(table)
-            .order_by(id_col)
-            .execute()
-        )
-        self._assert_duration_equal(rows[0][duration_col], d1)
-        self._assert_duration_equal(rows[1][duration_col], d2)
-        self._assert_duration_equal(rows[2][duration_col], d3)
-
-    @staticmethod
-    def _assert_version_equal(a: Version, b: Version) -> None:
-        assert a == b, f"{a!r} != {b!r}"
-
-    def test_semantic_version_field(self) -> None:
-        log.info("test_semantic_version_field")
-
-        from sqlalchemy.engine import create_engine
-        from sqlalchemy.sql.expression import select
-        from sqlalchemy.sql.schema import MetaData, Table
-
-        # As above:
-        engine = create_engine(SQLITE_MEMORY_URL, echo=True)
-        meta = MetaData()
-        meta.bind = engine
-
-        id_colname = 'id'
-        version_colname = 'version'
-        id_col = Column(id_colname, Integer, primary_key=True)
-        version_col = Column(version_colname, SemanticVersionColType)
-
-        table = Table('testtable', meta,
-                      id_col, version_col)
-        table.create()
-
-        v1 = Version("1.1.0")
-        v2 = Version("2.0.1")
-        v3 = Version("14.0.0")
-
-        table.insert().values([
-            {
-                id_colname: 1,
-                version_colname: v1,
-            },
-            {
-                id_colname: 2,
-                version_colname: v2,
-            },
-            {
-                id_colname: 3,
-                version_colname: v3,
-            },
-        ]).execute()
-        select_fields = [
-            id_col,
-            version_col,
-        ]
-        rows = list(
-            select(select_fields)
-            .select_from(table)
-            .order_by(id_col)
-            .execute()
-        )
-        self._assert_version_equal(rows[0][version_col], v1)
-        self._assert_version_equal(rows[1][version_col], v2)
-        self._assert_version_equal(rows[2][version_col], v3)
-
-
-# =============================================================================
-# main
-# =============================================================================
-# run with "python -m camcops_server.cc_modules.cc_sqla_coltypes -v" to be verbose  # noqa
-
-if __name__ == "__main__":
-    main_only_quicksetup_rootlogger(level=logging.DEBUG)
-    unittest.main()
